---
permalink: /functions
fbcontact: true
---

# Funktionen

Der KMUHelper ist ein Tool für Schweizer KMU, mit welchem die Buchhaltung erledigt werden kann.

Hier eine kleine Liste mit den wichtigsten Funktionen:

- Erfassen von Bestellungen
- Druck von QR-Rechnungen (DE, FR, IT, EN) -> [Beispiel](./assets/pdfs/example-invoice.pdf)
- Lagerverwaltung
- Kundenmanagement
- Kleine (Web-)App für unterwegs
- ... und noch viel mehr!

Anleitungen und Erklärungen zu den jeweiligen Funktionen finden Sie im [Handbuch](manual/README.md).

## Wichtige Infos

Bitte beachten Sie, dass der KMUHelper (zurzeit) nur für Bestellungen und KMU innerhalb Schweiz/Liechtenstein ausgelegt ist.

Ich übernehme KEINE GARANTIE bei fehlerhafter Programmierung meinerseits, bin aber gerne bereit, Ihr Problem so schnell wie möglich zu lösen. (Eröffnen Sie dazu ein sogenanntes ["Issue"](<{{ site.github.repository_url }}/issues>) oder [kontaktieren Sie mich](<{{ site.kontakt_url }}>).)

## Zurück

[Zurück zur Startseite](./README.md)
